# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   test61
# FileName:      db.py
# Author:       dengyuan
# Datetime:     2024/6/18 17:36
# Description:
# 命名规范：文件名全小写+下划线，类名大驼峰，方法和变量小写+下划线连接，
# 常量大写，变量和常量用名词，方法用动词
# ---------------------------------------------------------------------------
import pymysql

from study_requests.APIAutoTest_v3_1.common.read_basic_ini import ReadBasicIni


class DB:
    def __init__(self):
        ini = ReadBasicIni()
        try:
            self.conn = pymysql.connect(
                host=ini.connect_database_msg('host'),
                port=int(ini.connect_database_msg('port')),
                user=ini.connect_database_msg('user'),
                passwd=ini.connect_database_msg('passwd'),
                database=ini.connect_database_msg('database'),
                charset='utf8'
            )
            self.cursor = self.conn.cursor()
        except Exception as e:
            print("数据库连接错误或者游标对象创建错误：",e)
            raise e
    def close(self):
        """关闭游标对象和链接对象"""
        self.cursor.close()
        self.conn.close()

    def execute(self,sql):
        if isinstance(sql,str):
            try:
                res = self.cursor.execute(sql)
                self.conn.commit()
                if res == 1:
                    print("执行成功")
                else:
                    print("执行失败")
            except Exception as e:
                print('sql执行语句出错:',e)
        else:
            raise ValueError('sql语句必须为字符串')

    def select(self,sql):
        if isinstance(sql,str) and sql.strip().split(' ')[0].lower() == 'select':
            try:
                self.cursor.execute(sql)
                res= self.cursor.fetchall()
                print(res)
            except Exception as e:
                print('sql查询语句出错:',e)
            else:
                return res[0][0]
        else:
            raise ValueError('sql语句必须以select开头')

    def insert(self,sql,n):
        if isinstance(sql,str) and sql.strip().split(' ')[0].lower() == 'insert':
            try:
                for i in range(n):
                    res = self.cursor.execute(sql)
                    self.conn.commit()
                    if res == 1:
                        print("插入数据成功")
                    else:
                        print("插入数据失败")
            except Exception as e:
                print('sql插入语句出错:',e)
        else:
            raise ValueError('sql语句必须以insert开头')

    def update(self,sql):
        if isinstance(sql,str) and sql.strip().split(' ')[0].lower() == 'update':
            try:
                res = self.cursor.execute(sql)
                self.conn.commit()
                if res == 1:
                    print("更新数据成功")
                else:
                    print("更新数据失败")
            except Exception as e:
                print('sql修改语句出错:',e)
        else:
            raise ValueError('sql语句必须以update开头')

    def delete(self,sql):
        if isinstance(sql,str) and sql.strip().split(' ')[0].lower() == 'delete':
            try:
                res = self.cursor.execute(sql)
                self.conn.commit()
            except Exception as e:
                print('sql删除语句出错:',e)
            else:
                return res
        else:
            raise ValueError('sql语句必须以delete开头')

if __name__ == '__main__':
    db = DB()
    sql = """SELECT ID_ FROM uc_demension WHERE `CODE_`="adddem1";"""
    print(db.select(sql))
