# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   test61
# FileName:      read_excel.py
# Author:       dengyuan
# Datetime:     2024/7/9 11:05
# Description:
# 命名规范：文件名全小写+下划线，类名大驼峰，方法和变量小写+下划线连接，
# 常量大写，变量和常量用名词，方法用动词
# ---------------------------------------------------------------------------
import openpyxl

from study_requests.APIAutoTest_v3_1.common.read_basic_ini import ReadBasicIni
from study_requests.APIAutoTest_v3_1.common.read_ini import ReadIni
from study_requests.APIAutoTest_v3_1.common.read_json import read_json


class ReadExcel():
    def __init__(self,username):
        self.ini = ReadIni(username)

        case_data_path = self.ini.get_file_path("case")
        expect_data_path = self.ini.get_file_path("expect")
        sql_data_path = self.ini.get_file_path("sql")
        excel_path = self.ini.get_file_path("excel")
        table_name = self.ini.get_table_name('table')

        self.expect_data_dict = read_json(expect_data_path)
        self.sql_data_dict = read_json(sql_data_path)
        self.case_data_dict = read_json(case_data_path)
        try:
            wb = openpyxl.load_workbook(excel_path)
            self.ws = wb[table_name]
        except Exception as e:
            raise e
    def req_method(self,row):
        return self.__get_cell_value('f',row)

    def __get_cell_value(self,column,row):
        try:
            cell_value = self.ws[column+str(row)].value
        except Exception as e:
            raise e

        if cell_value is None:
            return None
        elif cell_value.strip():
            return cell_value.strip()

    def req_url(self,row):
        host = ReadBasicIni().get_url('test_host')
        value = self.__get_cell_value('g',row)
        if value:
            return host + value

    def case_mime(self,row):
        value = self.__get_cell_value('h', row)
        if value:
            return value.lower()

    def module_name(self,row):
        return self.__get_cell_value('B',row)

    def api_name(self,row):
        return self.__get_cell_value('C',row)

    def sql_type(self, row):
        sql_type = self.__get_cell_value('k', row)
        if sql_type:
            return sql_type.lower()

    def sql_data(self, row):
        sql_data = self.__get_cell_value('l', row)
        if sql_data:
            module_name = self.module_name(row)
            api_name = self.api_name(row)
            return self.sql_data_dict[module_name][api_name][sql_data]
    def update_key(self, row):
        return self.__get_cell_value('m', row)

    def case_data(self,row):
        case_data_key = self.__get_cell_value('i',row)
        if case_data_key is not None:
            module_name = self.module_name(row)
            api_name = self.api_name(row)
            return self.case_data_dict[module_name][api_name][case_data_key]

    def case_expect(self,row):
        case_expect_key = self.__get_cell_value('j', row)
        if case_expect_key:
            module_name = self.module_name(row)
            api_name = self.api_name(row)
            return self.expect_data_dict[module_name][api_name][case_expect_key]

    def get_data(self):
        list_data = []
        for row in range(2,self.ws.max_row+1):
            req_method = self.req_method(row)
            req_url = self.req_url(row)
            case_mime = self.case_mime(row)
            case_data = self.case_data(row)
            case_expect = self.case_expect(row)
            update_key = self.update_key(row)
            sql_type = self.sql_type(row)
            sql_data = self.sql_data(row)
            if req_method and req_url:
                row_list = [req_method, req_url, case_mime, case_data, case_expect, sql_type, sql_data, update_key]
                list_data.append(row_list)

        else:
            return list_data



if __name__ == '__main__':
    excel = ReadExcel("lao_zhang")
    # print(excel._ReadExcel__get_cell_value('h', 11))
    # print(excel._ReadExcel__get_cell_value('d', 2),excel.case_data(2),excel.case_expect(2))
    print(excel.get_data())